@@ -7,16 +7,16 @@ from git_monorepo.project_config import (
     GitMonorepoConfig,
     write_synchronized_commits,
     is_synchronized_commits_file_existing,
+    get_current_commit,
 )
 from git_monorepo.pull_command import env_extend
 
 
-def push():
+def push(force: bool):
     monorepo = read_config()
-    something_changed = False
 
     for folder_name, repo_location in monorepo.repos.items():
-        if is_repo_unchanged(monorepo, folder_name):
+        if is_repo_unchanged(monorepo, folder_name) and not force:
             print(
                 green(repo_location, bold=True),
                 green("->"),
@@ -25,14 +25,15 @@ def push():
             )
             continue
 
-        something_changed = True
-
         print(
             yellow(repo_location, bold=True),
             yellow("->"),
             yellow(folder_name, bold=True),
             yellow("PUSH", bold=True),
         )
+
+        initial_commit = get_current_commit(project_folder=monorepo.project_folder)
+
         subprocess.check_call(
             [
                 "git",
@@ -47,16 +48,16 @@ def push():
             env=env_extend(
                 {
                     "EDITOR": "git-monorepo-editor",
-                    "GIT_MONOREPO_EDITOR_MESSAGE": f"git-monorepo: Sync {folder_name}",
+                    "GIT_MONOREPO_EDITOR_MESSAGE": f"git-monorepo: push {folder_name}",
                 }
             ),
         )
 
-    if not something_changed and is_synchronized_commits_file_existing(monorepo):
-        return
+        current_commit = get_current_commit(project_folder=monorepo.project_folder)
 
-    # we need to update the last commit file with the new value
-    write_synchronized_commits(monorepo)
+        # we need to update the last commit file with the new value
+        # the commit is the current_commit, since this is already pushed
+        write_synchronized_commits(monorepo, repo=folder_name, commit=current_commit)
 
 
 def is_repo_unchanged(monorepo: GitMonorepoConfig, folder_name: str) -> bool:
